@@ -98,7 +98,18 @@ class TestScheduler(unittest.TestCase):
         sched.pause_sequence()
         self.assertTrue(sched.paused)
         sched.start_sequence()
-        sched.join()
+        while sched.time_points[0].status_code != 3:
+            time.sleep(0.1)
+        self.assertEqual(sched.completed_time_points, 1, 'one complete time point')
+        self.assertGreater(sched.remaining_time_points, 0, 'non-zero points remaining')
+        self.assertGreater(sched.triggered_time_points, 0, 'non-zero number triggered')
+        self.assertGreater(sched.uncompleted_time_points, 0, 'more than one uncompleted time point')
+        self.assertGreater(sched.total_time_points, sched.triggered_time_points, 'total greater than number triggered')
+        sched.join()  # wait for scheduler to complete
+        self.assertEqual(sched.remaining_time_points, 0, 'no more time points')
+        self.assertEqual(sched.triggered_time_points, sched.total_time_points, 'triggered count equals time points')
+        self.assertEqual(sched.completed_time_points, sched.total_time_points, 'complete count is accurate')
+        self.assertEqual(sched.uncompleted_time_points, 0, 'no uncompleted time points')
         self.assertFalse(sched.busy)
 
     def test_triggering(self):
@@ -167,9 +178,6 @@ class TestTimePointConditional(unittest.TestCase):
 
     def test_conditional(self):
         """tests the conditional which runs actions on specified timepoints"""
-        def check_conditional_return(tp, expected):
-            tp.wait_for_completion()
-            self.assertEqual(tp.action_returns['check_and_run'], expected)
 
         tp_nums = [1, 3, 5]
         condl_action = ExecuteOnTimePoints(
@@ -181,7 +189,7 @@ class TestTimePointConditional(unittest.TestCase):
             condl_action,
         )
 
-        sched.insert_time_point(0.2, number_of_points=6, relative_to='previous')
+        sched.insert_time_point(0.2, number_of_points=10, relative_to='previous')
         sched.start_sequence()
         sched.join()
         for ind, timepoint in enumerate(sched.time_points):
@@ -193,5 +201,5 @@ class TestTimePointConditional(unittest.TestCase):
             self.assertEqual(
                 timepoint.action_returns['dummy'],
                 expected,
-                msg='ensure expected timepoints executed'
+                msg=f'ensure timepoint {ind + 1} conditional execution was correct'
             )
